==> staffology-0.1.1-py3-none-any.whl: staffology/api/pay_schedule/get_all_pay_schedule.py <==
from typing import Any, Dict, List, Optional

import httpx

from ...client import Client
from ...models.pay_schedule import PaySchedule
from ...models.tax_year import TaxYear
from ...types import Response


def _get_kwargs(
    employer_id: str,
    tax_year: TaxYear,
    *,
    client: Client,
) -> Dict[str, Any]:
    url = "{}/employers/{employerId}/schedules/{taxYear}".format(
        client.base_url, employerId=employer_id, taxYear=tax_year
    )

    headers: Dict[str, str] = client.get_headers()
    cookies: Dict[str, Any] = client.get_cookies()

    return {
        "method": "get",
        "url": url,
        "headers": headers,
        "cookies": cookies,
        "timeout": client.get_timeout(),
    }


def _parse_response(*, response: httpx.Response) -> Optional[List[PaySchedule]]:
    if response.status_code == 200:
        response_200 = []
        _response_200 = response.json()
        for response_200_item_data in _response_200:
            response_200_item = PaySchedule.from_dict(response_200_item_data)

            response_200.append(response_200_item)

        return response_200
    return None


def _build_response(*, response: httpx.Response) -> Response[List[PaySchedule]]:
    return Response(
        status_code=response.status_code,
        content=response.content,
        headers=response.headers,
        parsed=_parse_response(response=response),
    )


def sync_detailed(
    employer_id: str,
    tax_year: TaxYear,
    *,
    client: Client,
) -> Response[List[PaySchedule]]:
    """Get PaySchedules

     Get all PaySchedules for the given TaxYear.

    Args:
        employer_id (str):
        tax_year (TaxYear):

    Returns:
        Response[List[PaySchedule]]
    """

    kwargs = _get_kwargs(
        employer_id=employer_id,
        tax_year=tax_year,
        client=client,
    )

    response = httpx.request(
        verify=client.verify_ssl,
        **kwargs,
    )

    return _build_response(response=response)


def sync(
    employer_id: str,
    tax_year: TaxYear,
    *,
    client: Client,
) -> Optional[List[PaySchedule]]:
    """Get PaySchedules

     Get all PaySchedules for the given TaxYear.

    Args:
        employer_id (str):
        tax_year (TaxYear):

    Returns:
        Response[List[PaySchedule]]
    """

    return sync_detailed(
        employer_id=employer_id,
        tax_year=tax_year,
        client=client,
    ).parsed


async def asyncio_detailed(
    employer_id: str,
    tax_year: TaxYear,
    *,
    client: Client,
) -> Response[List[PaySchedule]]:
    """Get PaySchedules

     Get all PaySchedules for the given TaxYear.

    Args:
        employer_id (str):
        tax_year (TaxYear):

    Returns:
        Response[List[PaySchedule]]
    """

    kwargs = _get_kwargs(
        employer_id=employer_id,
        tax_year=tax_year,
        client=client,
    )

    async with httpx.AsyncClient(verify=client.verify_ssl) as _client:
        response = await _client.request(**kwargs)

    return _build_response(response=response)


async def asyncio(
    employer_id: str,
    tax_year: TaxYear,
    *,
    client: Client,
) -> Optional[List[PaySchedule]]:
    """Get PaySchedules

     Get all PaySchedules for the given TaxYear.

    Args:
        employer_id (str):
        tax_year (TaxYear):

    Returns:
        Response[List[PaySchedule]]
    """

    return (
        await asyncio_detailed(
            employer_id=employer_id,
            tax_year=tax_year,
            client=client,
        )
    ).parsed

==> staffology-0.1.4-py3-none-any.whl: staffology/api/pay_schedule/get_all_pay_schedule.py <==
from typing import Any, Dict, List, Optional

import httpx
from staffology.propagate_exceptions import raise_staffology_exception

from ...client import Client
from ...models.pay_schedule import PaySchedule
from ...models.tax_year import TaxYear
from ...types import Response


def _get_kwargs(
    employer_id: str,
    tax_year: TaxYear,
    *,
    client: Client,
) -> Dict[str, Any]:
    url = "{}/employers/{employerId}/schedules/{taxYear}".format(
        client.base_url, employerId=employer_id, taxYear=tax_year
    )

    headers: Dict[str, str] = client.get_headers()
    cookies: Dict[str, Any] = client.get_cookies()

    return {
        "method": "get",
        "url": url,
        "headers": headers,
        "cookies": cookies,
        "timeout": client.get_timeout(),
    }


def _parse_response(*, response: httpx.Response) -> Optional[List[PaySchedule]]:
    if response.status_code == 200:
        response_200 = []
        _response_200 = response.json()
        for response_200_item_data in _response_200:
            response_200_item = PaySchedule.from_dict(response_200_item_data)

            response_200.append(response_200_item)

        return response_200
    return raise_staffology_exception(response)


def _build_response(*, response: httpx.Response) -> Response[List[PaySchedule]]:
    return Response(
        status_code=response.status_code,
        content=response.content,
        headers=response.headers,
        parsed=_parse_response(response=response),
    )


def sync_detailed(
    employer_id: str,
    tax_year: TaxYear,
    *,
    client: Client,
) -> Response[List[PaySchedule]]:
    """Get PaySchedules

     Get all PaySchedules for the given TaxYear.

    Args:
        employer_id (str):
        tax_year (TaxYear):

    Returns:
        Response[List[PaySchedule]]
    """

    kwargs = _get_kwargs(
        employer_id=employer_id,
        tax_year=tax_year,
        client=client,
    )

    response = httpx.request(
        verify=client.verify_ssl,
        **kwargs,
    )

    return _build_response(response=response)


def sync(
    employer_id: str,
    tax_year: TaxYear,
    *,
    client: Client,
) -> Optional[List[PaySchedule]]:
    """Get PaySchedules

     Get all PaySchedules for the given TaxYear.

    Args:
        employer_id (str):
        tax_year (TaxYear):

    Returns:
        Response[List[PaySchedule]]
    """

    return sync_detailed(
        employer_id=employer_id,
        tax_year=tax_year,
        client=client,
    ).parsed


async def asyncio_detailed(
    employer_id: str,
    tax_year: TaxYear,
    *,
    client: Client,
) -> Response[List[PaySchedule]]:
    """Get PaySchedules

     Get all PaySchedules for the given TaxYear.

    Args:
        employer_id (str):
        tax_year (TaxYear):

    Returns:
        Response[List[PaySchedule]]
    """

    kwargs = _get_kwargs(
        employer_id=employer_id,
        tax_year=tax_year,
        client=client,
    )

    async with httpx.AsyncClient(verify=client.verify_ssl) as _client:
        response = await _client.request(**kwargs)

    return _build_response(response=response)


async def asyncio(
    employer_id: str,
    tax_year: TaxYear,
    *,
    client: Client,
) -> Optional[List[PaySchedule]]:
    """Get PaySchedules

     Get all PaySchedules for the given TaxYear.

    Args:
        employer_id (str):
        tax_year (TaxYear):

    Returns:
        Response[List[PaySchedule]]
    """

    return (
        await asyncio_detailed(
            employer_id=employer_id,
            tax_year=tax_year,
            client=client,
        )
    ).parsed
